@@ -7,15 +7,16 @@ from .mapping import NounEndingMap
 from .replacements import (SearchResult, search_by_dictionary,
                            search_by_dictionary_plus_s, search_by_suggestions)
 from .speller import ensure_hunspell_nl, get_plural_nouns
-from .strategies.pluralize_bastard import pluralize_bastard
+from .strategies.pluralize_bastard_words import pluralize_bastard
 from .strategies.pluralize_by_hard_map import pluralize_by_hard_map
 from .strategies.pluralize_by_latin import pluralize_by_latin
 from .strategies.pluralize_eren import pluralize_eren
 from .strategies.pluralize_long_vowel import pluralize_long_vowel
 from .strategies.pluralize_man import pluralize_man
+from .strategies.pluralize_oren import pluralize_oren
 from .strategies.pluralize_with_en import pluralize_with_en
 from .strategies.pluralize_with_s import pluralize_with_s
-from .strategies.simple import pluralize_heid, pluralize_lui, pluralize_oren
+
 
 class AdvancedPluralizationResult:
 
@@ -41,8 +42,6 @@ def __pluralize(singular: str, ending_overrides: NounEndingMap = None) -> str:
         pluralize_by_hard_map(singular, ending_overrides) or \
         pluralize_eren(singular) or \
         pluralize_oren(singular) or \
-        pluralize_heid(singular) or \
-        pluralize_lui(singular) or \
         pluralize_man(singular) or \
         pluralize_by_latin(singular) or \
         pluralize_long_vowel(singular) or \
