@@ -1,4 +1,4 @@
-# Yeah, sometimes is is too hard to do it algoritmically, or I'm
+# Yeah, sometimes it is too hard to do it algoritmically, or I'm
 # just way too lazy, so here is a map for all those silly exceptions
 # that we like to have in Dutch.
 # Other words that end up here have plurals that are excepted by
@@ -7,6 +7,8 @@
 from ..mapping import NounEndingMap
 
 __hard_map = NounEndingMap({
+    "heid": "heden",
+    "lui": "lieden",
     "gelid": "gelederen",
     "lid": "leden",
     "schip": "schepen",
@@ -20,6 +22,12 @@ __hard_map = NounEndingMap({
     "glas": "glazen",
     "graf": "graven",  # added case for singlar
     "bh": "bh's",
+    "lasagne": "lasagna",
+    "smid": "smeden",
+    "tonic": "tonics",
+    "artikel": "artikelen",
+    "middel": "middelen",
+    "voer": "voer"
 })
 
 __only_for_singularize = NounEndingMap({
@@ -31,10 +39,9 @@ def pluralize_by_hard_map(singular: str, overrides: NounEndingMap) -> str:
 
     for nouns in [overrides, __hard_map]:
         if nouns:
-            map = nouns.get_plural_map()
-            for key in map:
-                if singular.endswith(key):
-                    return singular[0:0-len(key)] + map[key]
+            plural = nouns.pluralize_by_endings(singular)
+            if plural:
+                return plural
 
     return None
 
@@ -43,9 +50,9 @@ def singularize_by_hard_map(plural: str, overrides: NounEndingMap) -> str:
 
     for nouns in [overrides, __hard_map, __only_for_singularize]:
         if nouns:
-            map = nouns.get_singular_map()
-            for key in map:
-                if plural.endswith(key):
-                    return plural[0:0-len(key)] + map[key]
+            singular = nouns.singularize_by_endings(plural)
+            if singular:
+                return singular
 
     return None
+
